@@ -24,15 +24,15 @@
 #include <glib.h>
 #include <gcrypt.h>
 
-struct gvnc_dh;
+struct vnc_dh;
 
-struct gvnc_dh *gvnc_dh_new(gcry_mpi_t prime, gcry_mpi_t generator);
+struct vnc_dh *vnc_dh_new(gcry_mpi_t prime, gcry_mpi_t generator);
 
-gcry_mpi_t gvnc_dh_gen_secret(struct gvnc_dh *dh);
-gcry_mpi_t gvnc_dh_gen_key(struct gvnc_dh *dh, gcry_mpi_t inter);
-void gvnc_dh_free(struct gvnc_dh *dh);
+gcry_mpi_t vnc_dh_gen_secret(struct vnc_dh *dh);
+gcry_mpi_t vnc_dh_gen_key(struct vnc_dh *dh, gcry_mpi_t inter);
+void vnc_dh_free(struct vnc_dh *dh);
 
-void gvnc_mpi_to_bytes(const gcry_mpi_t value, guchar* result);
-gcry_mpi_t gvnc_bytes_to_mpi(const guchar* value);
+void vnc_mpi_to_bytes(const gcry_mpi_t value, guchar* result);
+gcry_mpi_t vnc_bytes_to_mpi(const guchar* value);
 
 #endif
